Learn R Programming

manymodelr (version 0.3.2)

add_model_residuals: Add model residuals

Description

A dplyr compatible convenience function to add residuals to a data set

Usage

add_model_residuals(model = NULL, old_data = NULL)

Arguments

model

A model object from `fit_model`

old_data

The data set to which predicted values will be added.

Value

A data.frame object with residuals added.

Examples

Run this code
# NOT RUN {
iris1 <- iris[1:50,]
iris2 <- iris[51:100,]
lm_model <- fit_model(iris1,"Sepal.Length","Sepal.Width","lm") 
head(add_model_residuals(lm_model,iris1))
# }

Run the code above in your browser using DataLab